nickva opened a new pull request, #6206:
URL: https://github.com/apache/couchdb/pull/6206

   For a while now we were able to issue a batch of preads to the couch_file 
[1]. We can use that to batch read `#doc{}` records. With this we can speed up 
the internal replicator, especially when copying lots of small documents 
between shards.
   
   Tested with small 1GB of 1KB docs, blew away a shard copy then re-created 
with the internal replicator:
   
     main: 113-118 sec
     pr: 81-85 sec
   
   About 1.4x faster or so.
   
   [1]
   
https://github.com/apache/couchdb/blob/eafed9939fe88de296d8875cf3b2ace5be3293cb/src/couch/src/couch_file.erl#L199
   


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: [email protected]

For queries about this service, please contact Infrastructure at:
[email protected]

Reply via email to